@@ -110,12 +110,12 @@ function(formula,data,gtmode="additive",trait.type="guess",propPs=1.0)
 	#out
 	if (is.null(Pc1df)) {
 		results <- data.frame(N=N,
-				effB = effB, se_effB = effB/sqrt(chi2.1df), chi2.1df = chi2.1df, P1df = P1df, 
+				effB = effB, se_effB = abs(effB)/sqrt(chi2.1df), chi2.1df = chi2.1df, P1df = P1df, 
 				effAB=effAB, effBB=effBB, chi2.2df = chi2.2df, P2df = P2df,
 				stringsAsFactors = FALSE)
 	} else {
 		results <- data.frame(N=N,
-				effB = effB, se_effB = effB/sqrt(chi2.1df), chi2.1df = chi2.1df, P1df = P1df, 
+				effB = effB, se_effB = abs(effB)/sqrt(chi2.1df), chi2.1df = chi2.1df, P1df = P1df, 
 				Pc1df = Pc1df, 
 				effAB=effAB, effBB=effBB, chi2.2df = chi2.2df, P2df = P2df,
 				stringsAsFactors = FALSE)
